@@ -31,8 +31,8 @@ class CommsChannelManager(models.Manager):
         # If the channel already existed we will need to join it
         # If we are already in the channel as we created it, then this is a No-Op
         try:
-            logger.info(f"Joining channel {name}")
-            settings.SLACK_CLIENT.join_channel(name)
+            logger.info(f"Joining channel {name} {channel_id}")
+            settings.SLACK_CLIENT.join_channel(channel_id)
         except SlackError as e:
             logger.error(f"Failed to join comms channel {e}")
             raise
