@@ -1,6 +1,6 @@
 import random
 
-import factory
+import factory.django
 from django.db.models.signals import post_save
 from faker import Factory
 
@@ -10,7 +10,7 @@ faker = Factory.create()
 
 
 @factory.django.mute_signals(post_save)
-class ActionFactory(factory.DjangoModelFactory):
+class ActionFactory(factory.django.DjangoModelFactory):
     class Meta:
         model = Action
 
